aft.c: Move definition of "buf" down a bit.
[paraslash.git] / error.h
diff --git a/error.h b/error.h
index 9b25e1f7050440905a8e8265b1ace51a497c333b..55bd3ba6b7a698f3d9370c9b24af67411daa4a3e 100644 (file)
--- a/error.h
+++ b/error.h
@@ -1,5 +1,5 @@
 /*
 /*
- * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -27,9 +27,14 @@ DEFINE_ERRLIST_OBJECT_ENUM;
 #define AFH_COMMON_ERRORS
 #define RBTREE_ERRORS
 #define RECV_ERRORS
 #define AFH_COMMON_ERRORS
 #define RBTREE_ERRORS
 #define RECV_ERRORS
+#define SEND_COMMON_ERRORS
 
 extern const char **para_errlist[];
 
 
 extern const char **para_errlist[];
 
+#define ACL_ERRORS \
+       PARA_ERROR(ACL_PERM, "access denied by acl"), \
+
+
 #define FSCK_ERRORS \
        PARA_ERROR(FSCK_SYNTAX, "fsck syntax error"), \
        PARA_ERROR(RANGE_VIOLATION, "range violation detected, very bad"), \
 #define FSCK_ERRORS \
        PARA_ERROR(FSCK_SYNTAX, "fsck syntax error"), \
        PARA_ERROR(RANGE_VIOLATION, "range violation detected, very bad"), \
@@ -63,7 +68,6 @@ extern const char **para_errlist[];
        PARA_ERROR(INDEX_CORRUPTION, "index corruption detected"), \
        PARA_ERROR(INVALID_OBJECT, "reference to invalid object"), \
        PARA_ERROR(STAT, "can not stat file"), \
        PARA_ERROR(INDEX_CORRUPTION, "index corruption detected"), \
        PARA_ERROR(INVALID_OBJECT, "reference to invalid object"), \
        PARA_ERROR(STAT, "can not stat file"), \
-       PARA_ERROR(RENAME, "rename failed"), \
        PARA_ERROR(WRITE, "write error"), \
        PARA_ERROR(LSEEK, "lseek error"), \
        PARA_ERROR(BUSY, "table is busy"), \
        PARA_ERROR(WRITE, "write error"), \
        PARA_ERROR(LSEEK, "lseek error"), \
        PARA_ERROR(BUSY, "table is busy"), \
@@ -255,8 +259,6 @@ extern const char **para_errlist[];
 
 
 #define STRING_ERRORS \
 
 
 #define STRING_ERRORS \
-       PARA_ERROR(MKSTEMP, "mkstemp error: unable to create tmp file"), \
-       PARA_ERROR(FCHMOD, "fchmod error: can not set mode"), \
        PARA_ERROR(ATOI_OVERFLOW, "value too large"), \
        PARA_ERROR(STRTOLL, "unknown strtoll error"), \
        PARA_ERROR(ATOI_NO_DIGITS, "no digits found in string"), \
        PARA_ERROR(ATOI_OVERFLOW, "value too large"), \
        PARA_ERROR(STRTOLL, "unknown strtoll error"), \
        PARA_ERROR(ATOI_NO_DIGITS, "no digits found in string"), \
@@ -303,7 +305,6 @@ extern const char **para_errlist[];
        PARA_ERROR(BAD_AUDIO_FILE_SUFFIX, "unknown suffix"), \
        PARA_ERROR(AUDIO_FORMAT, "audio format not recognized"), \
        PARA_ERROR(CHUNK, "unable to get chunk"), \
        PARA_ERROR(BAD_AUDIO_FILE_SUFFIX, "unknown suffix"), \
        PARA_ERROR(AUDIO_FORMAT, "audio format not recognized"), \
        PARA_ERROR(CHUNK, "unable to get chunk"), \
-       PARA_ERROR(SHORT_AFS_READ, "short read from afs socket"), \
        PARA_ERROR(NOFD, "did not receive open fd from afs"), \
 
 
        PARA_ERROR(NOFD, "did not receive open fd from afs"), \
 
 
@@ -317,8 +318,7 @@ extern const char **para_errlist[];
 
 
 #define HTTP_SEND_ERRORS \
 
 
 #define HTTP_SEND_ERRORS \
-       PARA_ERROR(WRITE_OK, "can not check whether fd is writable"), \
-       PARA_ERROR(SEND_QUEUED_CHUNK, "failed to send queued chunk"), \
+       PARA_ERROR(MAX_CLIENTS, "maximal number of clients exceeded"), \
 
 
 #define COMMAND_ERRORS \
 
 
 #define COMMAND_ERRORS \
@@ -347,13 +347,10 @@ extern const char **para_errlist[];
 
 
 #define DCCP_SEND_ERRORS \
 
 
 #define DCCP_SEND_ERRORS \
-       PARA_ERROR(DCCP_WRITE, "dccp write error"), \
 
 
 #define FD_ERRORS \
        PARA_ERROR(FGETS, "fgets error"), \
 
 
 #define FD_ERRORS \
        PARA_ERROR(FGETS, "fgets error"), \
-       PARA_ERROR(OPEN, "failed to open file"), \
-       PARA_ERROR(CHDIR_PERM, "insufficient permissions to chdir"), \
        PARA_ERROR(EMPTY, "file empty"), \
        PARA_ERROR(MMAP, "mmap error"), \
        PARA_ERROR(MUNMAP, "munmap failed"), \
        PARA_ERROR(EMPTY, "file empty"), \
        PARA_ERROR(MMAP, "mmap error"), \
        PARA_ERROR(MUNMAP, "munmap failed"), \
@@ -376,8 +373,6 @@ extern const char **para_errlist[];
        PARA_ERROR(HW_PARAMS, "unable to install hw params"), \
        PARA_ERROR(SW_PARAMS, "unable to install sw params"), \
        PARA_ERROR(BAD_PERIOD, "can not use period equal to buffer size"), \
        PARA_ERROR(HW_PARAMS, "unable to install hw params"), \
        PARA_ERROR(SW_PARAMS, "unable to install sw params"), \
        PARA_ERROR(BAD_PERIOD, "can not use period equal to buffer size"), \
-       PARA_ERROR(GET_XFER, "unable to obtain xfer align"), \
-       PARA_ERROR(SET_XFER, "snd_pcm_sw_params_set_xfer_align() failed"), \
        PARA_ERROR(ALSA_WRITE, "alsa write error"), \
        PARA_ERROR(PCM_OPEN, "unable to open pcm"), \
        PARA_ERROR(SND_PCM_INFO, "pcm info error"), \
        PARA_ERROR(ALSA_WRITE, "alsa write error"), \
        PARA_ERROR(PCM_OPEN, "unable to open pcm"), \
        PARA_ERROR(SND_PCM_INFO, "pcm info error"), \
@@ -449,27 +444,48 @@ extern const char **para_errlist[];
  */
 #define ERRNUM_TO_INDEX(num) (((1 << SS_SHIFT) - 1) & (num))
 
  */
 #define ERRNUM_TO_INDEX(num) (((1 << SS_SHIFT) - 1) & (num))
 
+/**
+ * This bit indicates whether a number is considered a system error number
+ * If yes, the system errno is just the result of clearing this bit from
+ * the given number.
+ */
 #define SYSTEM_ERROR_BIT 30
 
 #define SYSTEM_ERROR_BIT 30
 
+/** Check whether the system error bit is set. */
 #define IS_SYSTEM_ERROR(num) (!!((num) & (1 << SYSTEM_ERROR_BIT)))
 
 #define IS_SYSTEM_ERROR(num) (!!((num) & (1 << SYSTEM_ERROR_BIT)))
 
+/** Set the system error bit for the given number. */
 #define ERRNO_TO_PARA_ERROR(num) ((num) | (1 << SYSTEM_ERROR_BIT))
 
 #define ERRNO_TO_PARA_ERROR(num) ((num) | (1 << SYSTEM_ERROR_BIT))
 
-static inline int is_errno(int val, int _errno)
+/** Check whether a given number is a system error number.
+ *
+ * \param num The value to be checked.
+ * \param _errno The system error number.
+ *
+ * \return True if \a num is paraslash's representation of the system
+ * error identified by \a _errno.
+ */
+_static_inline_ int is_errno(int num, int _errno)
 {
 {
-       assert(val > 0 && _errno > 0);
-       return ERRNO_TO_PARA_ERROR(_errno) == val;
+       assert(num > 0 && _errno > 0);
+       return ERRNO_TO_PARA_ERROR(_errno) == num;
 }
 
 /**
  * Paraslash's version of strerror(3).
  *
 }
 
 /**
  * Paraslash's version of strerror(3).
  *
* Expands to the error text of \a num (a string constant).
  */
  */
-#define PARA_STRERROR(num) IS_SYSTEM_ERROR(num)? \
-       strerror((num) & ((1 << SYSTEM_ERROR_BIT) - 1)) : \
-       para_errlist[ERRNUM_TO_SS(num)] [ERRNUM_TO_INDEX(num)]
-
+_static_inline_ const char *para_strerror(int num)
+{
+       assert(num > 0);
+       if (IS_SYSTEM_ERROR(num))
+               return strerror((num) & ((1 << SYSTEM_ERROR_BIT) - 1));
+       else
+               return para_errlist[ERRNUM_TO_SS(num)][ERRNUM_TO_INDEX(num)];
+}
 /**
  * Define the error list for one subsystem.
  #
@@ -449,27 +444,48 @@ extern const char **para_errlist[];
  * Paraslash's version of strerror(3).
  *
- * Expands to the error text of \a num (a string constant).
+ * \param num The error number.
+ *
+ * \return The error text of \a num.
  */
  */
 /**
  * Define the error list for one subsystem.
  #